@@ -2,7 +2,7 @@
                           rksaveagent  -  description
                              -------------------
     begin                : Sun Aug 29 2004
-    copyright            : (C) 2004, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2004, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -57,7 +57,7 @@ RKSaveAgent::~RKSaveAgent () {
 
 bool RKSaveAgent::askURL () {
 	RK_TRACE (APP);
-	save_url = KFileDialog::getSaveFileName (save_url, "*.R");
+	save_url = KFileDialog::getSaveFileName (save_url, "*.RData *.rdata *.rda|R Data Files (*.RData *.rdata *.rda)\n*|All Files (*)");
 	if (save_url.isEmpty ()) {
 		if (when_done != DoNothing) {
 			if (KMessageBox::warningYesNo (0, i18n ("No filename given. Your data was NOT saved. Do you still want to proceed?")) != KMessageBox::Yes) when_done = DoNothing;
@@ -91,7 +91,6 @@ void RKSaveAgent::rCommandDone (RCommand *command) {
 		when_done = DoNothing;
 	} else {
 		RObjectList::getObjectList ()->setWorkspaceURL (save_url);
-		RKWardMainWindow::getMain ()->setCaption (QString::null);	// trigger update of caption
 	}
 	done ();
 }
