@@ -2,7 +2,7 @@
                           renvironmentobject  -  description
                              -------------------
     begin                : Wed Sep 27 2006
-    copyright            : (C) 2006 by Thomas Friedrichsmeier
+    copyright            : (C) 2006, 2009 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -23,6 +23,7 @@
 #include "robjectlist.h"
 #include "../rbackend/rinterface.h"
 #include "../settings/rksettingsmoduleobjectbrowser.h"
+#include "rkmodificationtracker.h"
 #include "../rkglobals.h"
 
 #include "../debug.h"
@@ -58,7 +59,12 @@ QString REnvironmentObject::getFullName () const {
 QString REnvironmentObject::makeChildName (const QString &short_child_name, bool misplaced) const {
 	RK_TRACE (OBJECTS);
 
-	if (type & GlobalEnv) return (short_child_name);
+	if (type & GlobalEnv) {
+		if (irregularShortName (short_child_name)) {
+			return (getShortName () + "$" + RObject::rQuote (short_child_name));
+		}
+		return (short_child_name);
+	}
 	if (type & ToplevelEnv) {
 /* Some items are placed outside of their native namespace. E.g. in package:boot item "motor". It can be retrieved using as.environment ("package:boot")$motor. This is extremly ugly. We need to give them (and only them) this special treatment. */
 // TODO: hopefully one day operator "::" will work even in those cases. So check back later, and remove after a sufficient amount of backwards compatibility time
@@ -101,6 +107,30 @@ void REnvironmentObject::updateFromR (RCommandChain *chain) {
 	RKGlobals::rInterface ()->issueCommand (command, chain);
 }
 
+void REnvironmentObject::updateFromR (RCommandChain *chain, const QStringList &current_symbols) {
+	RK_TRACE (OBJECTS);
+
+	// only needed for the assert at the end
+	int debug_baseline = 0;
+
+	// which children are missing?
+	for (int i = childmap.size () - 1; i >= 0; --i) {
+		RObject *object = childmap[i];
+		if (!current_symbols.contains (object->getShortName ())) {
+			if (!(RKGlobals::tracker ()->removeObject (object, 0, true))) debug_baseline++;
+		}
+	}
+
+	// which ones are new in the list?
+	for (int i = current_symbols.count () - 1; i >= 0; --i) {
+		RObject *child = findChildByName (current_symbols[i]);
+		if (!child) child = createPendingChild (current_symbols[i], i, false, false);
+		if (child->isPending ()) child->updateFromR (chain);
+	}
+
+	RK_ASSERT ((debug_baseline + current_symbols.count ()) == childmap.size ());
+}
+
 bool REnvironmentObject::updateStructure (RData *new_data) {
 	RK_TRACE (OBJECTS);
 	RK_ASSERT (new_data->getDataType () == RData::StructureVector);
