@@ -19,9 +19,6 @@
 
 #include "robject.h"
 
-#include <qpair.h>
-#include <qvaluelist.h>
-
 class RCommand;
 
 /**
@@ -37,7 +34,7 @@ public:
 
 /** reimplemented from RObject to handle function arguments */
 	bool updateStructure (RData *new_data);
-	QString printArgs ();
+	QString printArgs () const;
 protected:
 	unsigned int argcount;
 	QString *argnames;
