@@ -2,7 +2,7 @@
                           robject  -  description
                              -------------------
     begin                : Thu Aug 19 2004
-    copyright            : (C) 2004, 2006, 2007 by Thomas Friedrichsmeier
+    copyright            : (C) 2004, 2006, 2007, 2009 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -53,6 +53,12 @@ RObject::~RObject () {
 	delete [] classnames;
 }
 
+bool RObject::irregularShortName (const QString &name) {
+	// no trace
+	static const QRegExp invalidChars ("[^a-zA-z0-9\\._]");
+	return (name.contains (invalidChars));
+}
+
 QString RObject::getFullName () const {
 	RK_TRACE (OBJECTS);
 	return parent->makeChildName (RObject::name, type & Misplaced);
@@ -244,7 +250,16 @@ void RObject::writeMetaData (RCommandChain *chain) {
 void RObject::updateFromR (RCommandChain *chain) {
 	RK_TRACE (OBJECTS);
 
-	RCommand *command = new RCommand (".rk.get.structure (" + getFullName () + ", " + rQuote (getShortName ()) + ')', RCommand::App | RCommand::Sync | RCommand::GetStructuredData, QString::null, this, ROBJECT_UDPATE_STRUCTURE_COMMAND);
+	RCommand *command;
+	if (getContainer () == RObjectList::getGlobalEnv ()) {
+#warning TODO: find a generic solution
+// We handle objects directly in .GlobalEnv differently. That's to avoid forcing promises, when addressing the object directly. In the long run, .rk.get.structure should be reworked to simply not need the value-argument in any case.
+		 command = new RCommand (".rk.get.structure.global (" + rQuote (getShortName ()) + ')', RCommand::App | RCommand::Sync | RCommand::GetStructuredData, QString::null, this, ROBJECT_UDPATE_STRUCTURE_COMMAND);
+	} else {
+		RK_ASSERT (false);	// non-catastrophic, but do we get here?
+
+		command = new RCommand (".rk.get.structure (" + getFullName () + ", " + rQuote (getShortName ()) + ')', RCommand::App | RCommand::Sync | RCommand::GetStructuredData, QString::null, this, ROBJECT_UDPATE_STRUCTURE_COMMAND);
+	}
 	RKGlobals::rInterface ()->issueCommand (command, chain);
 }
 
