@@ -40,6 +40,7 @@
 #include "../settings/rksettings.h"
 #include "../core/robjectlist.h"
 #include "../misc/rkprogresscontrol.h"
+#include "../misc/rkstandardicons.h"
 
 #include "../debug.h"
 
@@ -278,9 +279,6 @@ LoadUnloadWidget::LoadUnloadWidget (RKLoadLibsDialog *dialog, QWidget *p_widget)
 	
 	QVBoxLayout *mvbox = new QVBoxLayout (this);
 	mvbox->setContentsMargins (0, 0, 0, 0);
-	QLabel *label = new QLabel (i18n ("There are no safeguards against removing essential packages. For example, unloading \"rkward\" will prevent this application from running properly. Please be careful about the packages you unload."), this);
-	label->setWordWrap (true);
-	mvbox->addWidget (label);
 	
 	QHBoxLayout *hbox = new QHBoxLayout ();
 	mvbox->addLayout (hbox);
@@ -295,16 +293,16 @@ LoadUnloadWidget::LoadUnloadWidget (RKLoadLibsDialog *dialog, QWidget *p_widget)
 	hbox->addLayout (loadedvbox);
 	loadedvbox->setContentsMargins (0, 0, 0, 0);
 	
-	label = new QLabel (i18n ("Installed packages"), this);
+	QLabel *label = new QLabel (i18n ("Installed packages"), this);
 	installed_view = new QTreeWidget (this);
 	installed_view->setHeaderLabels (QStringList () << i18n ("Name") << i18n ("Title") << i18n ("Version") << i18n ("Location"));
 	installed_view->setSelectionMode (QAbstractItemView::ExtendedSelection);
 	instvbox->addWidget (label);
 	instvbox->addWidget (installed_view);
 	
-	load_button = new QPushButton (i18n ("Load"), this);
+	load_button = new QPushButton (RKStandardIcons::getIcon (RKStandardIcons::ActionAddRight), i18n ("Load"), this);
 	connect (load_button, SIGNAL (clicked ()), this, SLOT (loadButtonClicked ()));
-	detach_button = new QPushButton (i18n ("Unload"), this);
+	detach_button = new QPushButton (RKStandardIcons::getIcon (RKStandardIcons::ActionRemoveLeft), i18n ("Unload"), this);
 	connect (detach_button, SIGNAL (clicked ()), this, SLOT (detachButtonClicked ()));
 	buttonvbox->addStretch (1);
 	buttonvbox->addWidget (load_button);
@@ -318,12 +316,16 @@ LoadUnloadWidget::LoadUnloadWidget (RKLoadLibsDialog *dialog, QWidget *p_widget)
 	loadedvbox->addWidget (label);
 	loadedvbox->addWidget (loaded_view);
 
+	connect (loaded_view, SIGNAL (itemSelectionChanged()), this, SLOT (updateButtons()));
+	connect (installed_view, SIGNAL (itemSelectionChanged()), this, SLOT (updateButtons()));
+
 	connect (dialog, SIGNAL (okClicked ()), this, SLOT (ok ()));
 	connect (dialog, SIGNAL (applyClicked ()), this, SLOT (apply ()));
 	connect (dialog, SIGNAL (cancelClicked ()), this, SLOT (cancel ()));
 	connect (this, SIGNAL (destroyed ()), dialog, SLOT (childDeleted ()));
 
 	updateInstalledPackages ();
+	updateButtons ();
 }
 
 LoadUnloadWidget::~LoadUnloadWidget () {
@@ -337,6 +339,7 @@ void LoadUnloadWidget::rCommandDone (RCommand *command) {
 		RK_ASSERT (command->getDataLength () == 4);
 
 		installed_view->clear ();
+		installed_view->setSortingEnabled (false);
 
 		RData *package = command->getStructureVector ()[0];
 		RData *title = command->getStructureVector ()[1];
@@ -355,6 +358,7 @@ void LoadUnloadWidget::rCommandDone (RCommand *command) {
 			item->setText (3, libpath->getStringVector ()[i]);
 		}
 		installed_view->resizeColumnToContents (0);
+		installed_view->setSortingEnabled (true);
 	} else if (command->getFlags () == GET_LOADED_PACKAGES) {
 		RK_ASSERT (command->getDataType () == RData::StringVector);
 
@@ -363,6 +367,13 @@ void LoadUnloadWidget::rCommandDone (RCommand *command) {
 		for (unsigned int i=0; i < command->getDataLength (); ++i) {
 			QTreeWidgetItem* item = new QTreeWidgetItem (loaded_view);
 			item->setText (0, command->getStringVector ()[i]);
+			if (RKSettingsModuleRPackages::essentialPackages ().contains (command->getStringVector ()[i])) {
+#if QT_VERSION >= 0x040400
+				item->setFlags (Qt::NoItemFlags);
+#else
+				item->setFlags (0);
+#endif
+			}
 		}
 		loaded_view->resizeColumnToContents (0);
 		setEnabled (true);
@@ -386,15 +397,17 @@ void LoadUnloadWidget::updateInstalledPackages () {
 void LoadUnloadWidget::loadButtonClicked () {
 	RK_TRACE (DIALOGS);
 
+	loaded_view->clearSelection ();
 	QList<QTreeWidgetItem*> sel = installed_view->selectedItems ();
 	for (int i = 0; i < sel.size (); ++i) {
-		QTreeWidgetItem* installed = sel[0];
+		QString package_name = sel[i]->text (0);
 
 		// is this package already loaded?
-		QList<QTreeWidgetItem*> loaded = loaded_view->findItems (installed->text (0), Qt::MatchExactly, 0);
+		QList<QTreeWidgetItem*> loaded = loaded_view->findItems (package_name, Qt::MatchExactly, 0);
 		if (loaded.isEmpty ()) {
 			QTreeWidgetItem* item = new QTreeWidgetItem (loaded_view);
-			item->setText (0, installed->text (0));
+			item->setText (0, package_name);
+			item->setSelected (true);
 		}
 	}
 }
@@ -402,12 +415,29 @@ void LoadUnloadWidget::loadButtonClicked () {
 void LoadUnloadWidget::detachButtonClicked () {
 	RK_TRACE (DIALOGS);
 
+	installed_view->clearSelection ();
 	QList<QTreeWidgetItem*> sel = loaded_view->selectedItems ();
 	for (int i = 0; i < sel.size (); ++i) {
-		delete (sel[i]);	// remove from list
+		QString package_name = sel[i]->text (0);
+
+		delete (sel[i]);	// remove from list of loaded packages
+
+		// select corresponding package in list of available packages
+		QList<QTreeWidgetItem*> installed = installed_view->findItems (package_name, Qt::MatchExactly, 0);
+		if (!installed.isEmpty ()) {
+			//RK_ASSERT (installed.count () == 1); // In fact, several versions of one package can be installed in several library locations
+			installed[0]->setSelected (true);
+		}
 	}
 }
 
+void LoadUnloadWidget::updateButtons () {
+	RK_TRACE (DIALOGS);
+
+	detach_button->setEnabled (!loaded_view->selectedItems ().isEmpty ());
+	load_button->setEnabled (!installed_view->selectedItems ().isEmpty ());
+}
+
 void LoadUnloadWidget::ok () {
 	RK_TRACE (DIALOGS);
 	doLoadUnload ();
@@ -433,21 +463,28 @@ void LoadUnloadWidget::doLoadUnload () {
 	for (int i = 0; i < loaded_view->topLevelItemCount (); ++i) {
 		QTreeWidgetItem* loaded = loaded_view->topLevelItem (i);
 		if (!prev_packages.contains (loaded->text (0))) {
-			RCommand *command = new RCommand ("library (\"" + loaded->text (0) + "\")", RCommand::App | RCommand::ObjectListUpdate, QString::null, this, LOAD_PACKAGE_COMMAND);
+			RCommand *command = new RCommand ("library (\"" + loaded->text (0) + "\")", RCommand::App | RCommand::ObjectListUpdate);
 			control->addRCommand (command);
 			RKGlobals::rInterface ()->issueCommand (command, parent->chain);
 		}
 	}
 	
 	// detach packages previously attached
+	QStringList packages_to_remove;
 	for (QStringList::Iterator it = prev_packages.begin (); it != prev_packages.end (); ++it) {
 		QList<QTreeWidgetItem*> loaded = loaded_view->findItems ((*it), Qt::MatchExactly, 0);
-		if (loaded.isEmpty ()) {		// no longer in the list
-			RCommand *command = new RCommand ("detach (package:" + (*it) + ')', RCommand::App | RCommand::ObjectListUpdate, QString (), this, LOAD_PACKAGE_COMMAND);
-			control->addRCommand (command);
-			RKGlobals::rInterface ()->issueCommand (command, parent->chain);
+		if (loaded.isEmpty ()) {	// no longer in the list
+			packages_to_remove.append ("package:" + *it);
 		}
 	}
+	if (!packages_to_remove.isEmpty ()) {
+		QStringList messages = RObjectList::getObjectList ()->detachPackages (packages_to_remove, parent->chain, control);
+		if (!messages.isEmpty ()) KMessageBox::sorry (this, messages.join ("\n"));
+	}
+
+	// find out, when we're done
+	RCommand *command = new RCommand (QString (), RCommand::EmptyCommand, QString (), this, LOAD_PACKAGE_COMMAND);
+	RKGlobals::rInterface ()->issueCommand (command, parent->chain);
 
 	control->doNonModal (true);
 }
