@@ -2,7 +2,7 @@
                           rkcomponentmap.h  -  description
                              -------------------
     begin                : Thu May 12 2005
-    copyright            : (C) 2005, 2006, 2007 by Thomas Friedrichsmeier
+    copyright            : (C) 2005, 2006, 2007, 2009 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -43,6 +43,7 @@ enum RKComponentType {
 
 class RKComponent;
 class RKComponentMap;
+class RCommandChain;
 class RKStandardComponent;
 class QWidget;
 class KActionCollection;
@@ -68,6 +69,9 @@ public:
 	QString getAttributeLabel (const QString &attribute_id);
 	bool hasAttribute (const QString &attribute_id);
 	void addAttribute (const QString &id, const QString &value, const QString &label);
+	void setAccessible (bool accessible) { is_accessible = accessible; };
+/** Returns whether this component is accessible from the menu, somewhere (else it might be in a context) */
+	bool isAccessible () const { return is_accessible; };
 public slots:
 /** Slot called, when the menu-item for this component is selected. Responsible for creating the GUI. */
 	void activated ();
@@ -82,6 +86,8 @@ protected:
 	typedef QPair<QString, QString> AttributeValue;
 	typedef QMap<QString, AttributeValue> AttributeMap;
 	AttributeMap *attributes;
+private:
+	bool is_accessible;
 };
 
 #include <qmap.h>
@@ -164,6 +170,15 @@ public:
 	static void initialize ();
 /** returns the context identified by id */
 	static RKContextMap *getContext (const QString &id);
+
+	enum ComponentInvocationMode {
+		ManualSubmit,
+		AutoSubmit,
+		AutoSubmitOrFail
+	};
+/** invokes the specified component as toplevel
+@param message If a non-null pointer to QString is given, error messages are written into this string *instead* of being displayed */
+	static bool invokeComponent (const QString &component_id, const QStringList &serialized_settings, ComponentInvocationMode submit_mode = ManualSubmit, QString *message=0, RCommandChain *in_chain = 0);
 private:
 /** typedef for easy reference to iterator */
 	typedef QMap<QString, RKComponentHandle*> ComponentMap;
