@@ -442,7 +442,7 @@ RKComponentPropertyDouble::RKComponentPropertyDouble (QObject *parent, bool requ
 
 	validator = new QDoubleValidator (this);		// accepts all ints initially
 	RKComponentPropertyDouble::default_value = default_value;
-	precision = 6;
+	precision = 2;
 	internalSetValue (default_value);
 }
 
@@ -587,7 +587,16 @@ void RKComponentPropertyDouble::internalSetValue (double new_value) {
 	RK_TRACE (PLUGIN);
 
 	current_value = new_value;
-	_value = QString::number (current_value, 'f', precision);
+
+	// what we want is AT LEAST *precision digits, more if required. I'm sure there's a nifty algorithm for that, but this hack does the trick:
+	_value = QString::number (current_value, 'f', 9);	// 9 is an arbitrary limit to counter floating point jitter
+	int decimal = _value.indexOf ('.');
+	if (decimal >= 0) {
+		int min_digit = decimal + precision + 1;
+		while ((min_digit < _value.length ()) && _value.endsWith ('0')) _value.chop (1);
+	}
+	if (_value.endsWith ('.')) _value.chop (1);
+
 	is_valid = ((new_value >= validator->bottom ()) && (new_value <= validator->top ()));
 	if (!is_valid) current_value = default_value;
 }
