@@ -2,7 +2,7 @@
                           rkformula  -  description
                              -------------------
     begin                : Thu Aug 12 2004
-    copyright            : (C) 2004, 2006 by Thomas Friedrichsmeier
+    copyright            : (C) 2004, 2006, 2007 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -23,13 +23,13 @@
 #include <qmap.h>
 #include "../core/robject.h"
 
-class QListView;
 class QPushButton;
 class QButtonGroup;
 class QWidget;
 class QSpinBox;
-class QListViewItem;
 class QDomElement;
+class QTreeWidget;
+class QTreeWidgetItem;
 
 /**
 @author Thomas Friedrichsmeier
@@ -68,8 +68,8 @@ private:
 	QButtonGroup *type_selector;
 	
 	QWidget *custom_model_widget;
-	QListView *model_view;
-	QListView *predictors_view;
+	QTreeWidget *model_view;
+	QTreeWidget *predictors_view;
 	QPushButton *add_button;
 	QPushButton *remove_button;
 	QSpinBox *level_box;
@@ -78,23 +78,19 @@ private:
 	void makeModelString ();
 	QString mangleName (RObject *var);
 	
-	typedef QMap<QListViewItem*, RObject*> ItemMap;
-	ItemMap item_map;
+	typedef QMap<QTreeWidgetItem*, RObject*> ItemMap;
+	ItemMap predictors_map;
 	
 	struct Interaction {
 		int level;
-		RObjectPtr* vars;
+		RObject::ObjectList vars;
 	};
 	
-	typedef QMap<QListViewItem*, Interaction> InteractionMap;
+	typedef QMap<QTreeWidgetItem*, Interaction> InteractionMap;
 	InteractionMap interaction_map;
 	
-	typedef QMap<int, QListViewItem*> LevelMap;
-	LevelMap level_map;
-	
-	/** recursively cross the given source variables on level level. Returns the resulting terms in an array. The number
-	of interactions generated is stored in count */
-	Interaction *makeInteractions (int level, const RObjectPtr *source_vars, int source_count, int *count);
+	/** recursively cross the given source variables on level level. Returns the resulting terms in an QList */
+	QList<Interaction> makeInteractions (int level, RObject::ObjectList);
 };
 
 #endif
