@@ -1,7 +1,7 @@
 // globals
 var options;
 
-include ("plot_dist_common.php");
+include ('plot_dist_common.js');
 
 function getParameters () {
 	options['llim'] = getValue ("llim");
