@@ -25,9 +25,25 @@
 
 #define MAX_RECEIVERS 3
 
+RCommandBase::RCommandBase (bool is_chain) {
+	is_command_chain = is_chain;
+	RCommandBase::parent = 0;
+}
+
+RCommand* RCommandBase::commandPointer () {
+	if (is_command_chain) return 0;
+	return static_cast<RCommand*> (this);
+}
+
+RCommandChain* RCommandBase::chainPointer () {
+	if (!is_command_chain) return 0;
+	return static_cast<RCommandChain*> (this);
+}
+
+
 int RCommand::next_id = 0;
 
-RCommand::RCommand(const QString &command, int type, const QString &rk_equiv, RCommandReceiver *receiver, int flags) : RData () {
+RCommand::RCommand(const QString &command, int type, const QString &rk_equiv, RCommandReceiver *receiver, int flags) : RData (), RCommandBase (false) {
 	RK_TRACE (RBACKEND);
 	_id = next_id++;
 // if we ever submit enough commands to get a buffer overflow, use only positive numbers.
@@ -36,7 +52,7 @@ RCommand::RCommand(const QString &command, int type, const QString &rk_equiv, RC
 	}
 	_type = type;
 	_flags = flags;
-	if (type & Plugin) _command = command.stripWhiteSpace ();
+	if (type & Plugin) _command = command.trimmed ();
 	else _command = command;
 	if (_command.isEmpty ()) _type |= EmptyCommand;
 	status = 0;
@@ -50,7 +66,7 @@ RCommand::RCommand(const QString &command, int type, const QString &rk_equiv, RC
 RCommand::~RCommand(){
 	RK_TRACE (RBACKEND);
 
-	for (QValueList<ROutput*>::iterator it = output_list.begin (); it != output_list.end (); ++it) {
+	for (QList<ROutput*>::const_iterator it = output_list.constBegin (); it != output_list.constEnd (); ++it) {
 		delete (*it);
 	}
 	// The output_list itself is cleared automatically
