@@ -2,7 +2,7 @@
                           rthread  -  description
                              -------------------
     begin                : Mon Aug 2 2004
-    copyright            : (C) 2004, 2006, 2007, 2008, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2004, 2006, 2007, 2008, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -19,6 +19,7 @@
 #include "rinterface.h"
 #include "rcommandstack.h"
 #include "../settings/rksettingsmoduler.h"
+#include "../settings/rksettingsmoduleoutput.h"
 #include "../settings/rksettingsmodulegeneral.h"
 #include "../rkglobals.h"
 #include "../rkward.h"		// for startup options
@@ -494,6 +495,8 @@ int RThread::initialize () {
 	if (error) status |= LibLoadFail;
 	runCommandInternal (QString ("stopifnot(.rk.app.version==\"%1\")\n").arg (VERSION), &error);
 	if (error) status |= LibLoadFail;
+	runCommandInternal (".rk.fix.assignments ()\n", &error);
+	if (error) status |= LibLoadFail;
 
 // find out about standard library locations
 	unsigned int c;
@@ -514,7 +517,7 @@ int RThread::initialize () {
 	delete [] help_base_url;
 
 // apply user configurable run time options
-	QStringList commands = RKSettingsModuleR::makeRRunTimeOptionCommands () + RKSettingsModuleRPackages::makeRRunTimeOptionCommands ();
+	QStringList commands = RKSettingsModuleR::makeRRunTimeOptionCommands () + RKSettingsModuleRPackages::makeRRunTimeOptionCommands () + RKSettingsModuleOutput::makeRRunTimeOptionCommands ();
 	for (QStringList::const_iterator it = commands.begin (); it != commands.end (); ++it) {
 		runCommandInternal ((*it).toLocal8Bit (), &error);
 		if (error) {
