@@ -2,7 +2,7 @@
                           rkconsole  -  description
                              -------------------
     begin                : Thu Aug 19 2004
-    copyright            : (C) 2004, 2006, 2007, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2004, 2006, 2007, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -144,6 +144,43 @@ RKConsole::~RKConsole () {
 	RKSettingsModuleConsole::saveCommandHistory (commands_history);
 }
 
+QAction* RKConsole::addProxyAction (const QString& actionName, const QString& label) {
+	RK_TRACE (APP);
+	RK_ASSERT (getPart ());
+	RK_ASSERT (view);
+
+	// katepart has more than one actionCollection
+	QList<KActionCollection*> acs = view->findChildren<KActionCollection*>();
+	acs.append (view->actionCollection ());
+
+	QAction* found = 0;
+	foreach (KActionCollection* ac, acs) {
+		found = ac->action (actionName);
+		if (found) break;
+	}
+
+	if (found) {
+		QAction* ret = new KAction (getPart ());
+		if (label.isEmpty ()) ret->setText (found->text ());
+		else ret->setText (label);
+		ret->setIcon (found->icon ());
+		ret->setIconText (found->iconText ());
+		ret->setToolTip (found->toolTip ());
+		ret->setStatusTip (found->statusTip ());
+		ret->setCheckable (found->isCheckable ());
+		ret->setChecked (found->isChecked ());
+		// TODO: ideally, we'd also relay enabledness, checked state, etc. That would probably require a separate class,
+		// and is not currently needed for the actions that we copy
+		connect (ret, SIGNAL (triggered(bool)), found, SLOT (trigger()));
+		connect (ret, SIGNAL (toggled(bool)), found, SLOT (toggle()));
+
+		getPart ()->actionCollection ()->addAction (actionName, ret);
+		return ret;
+	} else {
+		return 0;
+	}
+}
+
 void RKConsole::triggerEditAction (QString name) {
 	RK_TRACE (APP);
 
@@ -167,9 +204,12 @@ bool RKConsole::handleKeyPress (QKeyEvent *e) {
 	command_was_piped = false;
 
 	if (para < doc->lines () - 1 || pos < prefix.length ()) {	// not inside the last line?
-		int t = (int) pos;					// adjust position before interpreting keystroke
-		if (prefix.length()>pos) t=prefix.length ();
-		view->setCursorPosition (KTextEditor::Cursor (doc->lines () -1, t));
+		int key = e->key ();
+		if ((key != Qt::Key_Shift) && (key != Qt::Key_Control) && (key != Qt::Key_Meta) && (key != Qt::Key_Alt)) {
+			int t = (int) pos;					// adjust position before interpreting non-modifier keystroke
+			if (prefix.length()>pos) t=prefix.length ();
+			view->setCursorPosition (KTextEditor::Cursor (doc->lines () -1, t));
+		}
 	}
 
 	if (view->selection ()) {
@@ -739,14 +779,6 @@ int RKConsole::currentCursorPosition (){
 	return(c.column ());
 }
 
-//KDE4 still needed? (see ctor)
-void RKConsole::unplugAction(const QString &action, KActionCollection* ac) {
-	QAction* a = ac->action (action);
-	if( a ){
-		a->setEnabled (false);
-	}
-}
-
 int RKConsole::currentCursorPositionInCommand(){
 	RK_TRACE (APP);
 	return(currentCursorPosition() - prefix.length());
@@ -797,9 +829,9 @@ void RKConsole::showContextHelp () {
 void RKConsole::initializeActions (KActionCollection *ac) {
 	RK_TRACE (APP);
 
-	context_help_action = RKStandardActions::functionHelp (this, "function_reference", this, SLOT(showContextHelp()));
+	context_help_action = RKStandardActions::functionHelp (this, this, SLOT(showContextHelp()));
 
-	run_selection_action = RKStandardActions::runSelection (this, "run_selection", this, SLOT (runSelection()));
+	run_selection_action = RKStandardActions::runSelection (this, this, SLOT (runSelection()));
 
 	interrupt_command_action = ac->addAction ("interrupt", this, SLOT (slotInterruptCommand()));
 	interrupt_command_action->setText (i18n ("Interrupt running command"));
@@ -813,10 +845,18 @@ void RKConsole::initializeActions (KActionCollection *ac) {
 	copy_literal_action = ac->addAction ("rkconsole_copy_literal", this, SLOT (literalCopy()));
 	copy_literal_action->setText (i18n ("Copy selection literally"));
 
+	RKStandardActions::pasteSpecial (this, this, SLOT (submitBatch(const QString&)));
+
 	ac->addAction (KStandardAction::Clear, "rkconsole_clear", this, SLOT (clear()));
 	paste_action = ac->addAction (KStandardAction::Paste, "rkconsole_paste", this, SLOT (paste()));
 	QAction *action = ac->addAction ("rkconsole_configure", this, SLOT (configure()));
 	action->setText (i18n ("Configure"));
+
+	addProxyAction ("file_print", i18n ("Print Console"));
+	addProxyAction ("file_export_html");
+	addProxyAction ("view_dynamic_word_wrap");
+	addProxyAction ("view_inc_font_sizes");
+	addProxyAction ("view_dec_font_sizes");
 }
 
 void RKConsole::pipeUserCommand (const QString &command) {
