@@ -2,7 +2,7 @@
                           rkconsole  -  description
                              -------------------
     begin                : Thu Aug 19 2004
-    copyright            : (C) 2004, 2006, 2007 by Thomas Friedrichsmeier
+    copyright            : (C) 2004, 2006, 2007, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -55,9 +55,6 @@ public:
 /** Destructor */
 	~RKConsole ();
 
-/** Submits a batch of commands, line by line.
-\param batch a QString containing the batch of commands to be executed */
-	void submitBatch (const QString &batch);
 /** Returns the command currently being edited (not executed yet) */
 	QString currentCommand ();
 /** Returns the current cursor position. Returns the column on which is the cursor.  */
@@ -131,10 +128,12 @@ friend class RKConsolePart;
 	const char *nprefix;
 /** This string stores the continuation prefix. */
 	const char *iprefix;
-/** This function unplugs a KAction
-\param action the KAction to be unplugged
-\param ac the action collection from which to retrieve the KAction*/
-	void unplugAction (const QString &action, KActionCollection* ac);
+
+/** Create a proxy for the katepart action of the same name. The action is added to the actioncollection, automatically. Also any icon and label (but not shorcut) is copied.
+@param actionName Identifier of the action in katepartui.rc and rkconsolepart.rc
+@param label Label for the proxy action. If empty (default) copy the label from the katepartui
+@returns a pointer to the proxy action */
+	QAction* addProxyAction (const QString& actionName, const QString& label=QString ());
 
 	QString cleanedSelection ();
 
@@ -179,6 +178,10 @@ public slots:
 /** interrupt current command. */
 	void slotInterruptCommand ();
 	void runSelection ();
+
+/** Submits a batch of commands, line by line.
+\param batch a QString containing the batch of commands to be executed */
+	void submitBatch (const QString &batch);
 };
 
 /** A part interface to RKConsole. Provides the context-help functionality
