@@ -2,7 +2,7 @@
                           rkward.cpp  -  description
                              -------------------
     begin                : Tue Oct 29 20:06:08 CET 2002
-    copyright            : (C) 2002, 2005, 2006, 2007, 2008, 2009 by Thomas Friedrichsmeier 
+    copyright            : (C) 2002, 2005, 2006, 2007, 2008, 2009, 2010 by Thomas Friedrichsmeier 
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -30,7 +30,7 @@
 // include files for KDE
 #include <kiconloader.h>
 #include <kmessagebox.h>
-#include <kfiledialog.h>
+#include <kencodingfiledialog.h>
 #include <kmenubar.h>
 #include <kstatusbar.h>
 #include <klocale.h>
@@ -85,6 +85,7 @@
 
 #include "agents/showedittextfileagent.h"	// TODO: see below: needed purely for linking!
 #include "dialogs/rkreadlinedialog.h"	// TODO: see below: needed purely for linking!
+#include "dialogs/rkselectlistdialog.h"	// TODO: see below: needed purely for linking!
 #include "windows/detachedwindowcontainer.h"	// TODO: see below: needed purely for linking!
 #include "dataeditor/rkeditordataframe.h"	// TODO: see below: needed purely for linking!
 #include "agents/rkeditobjectagent.h"	// TODO: see below: needed purely for linking!
@@ -93,6 +94,7 @@
 void bogusCalls () {
 	ShowEditTextFileAgent::showEditFiles (0);		// TODO: AAAAAAAARGGGH!!!! It won't link without this bogus line!!!
 	RKReadLineDialog::readLine (0, QString(), QString(), 0, 0);	// TODO: see above
+	RKSelectListDialog::doSelect (0, QString(), QStringList(), QStringList(), false);	// TODO: see above
 	new RKEditorDataFrame (0, 0);
 	DetachedWindowContainer (0);
 	new RKWorkplaceView (0);
@@ -292,6 +294,7 @@ void RKWardMainWindow::startR () {
 
 	RKGlobals::rinter = new RInterface ();
 	new RObjectList ();
+	connect (RObjectList::getObjectList (), SIGNAL (workspaceUrlChanged(const KUrl&)), this, SLOT (addWorkspaceUrl(const KUrl&)));
 
 	RKGlobals::rInterface ()->startThread ();
 
@@ -322,9 +325,14 @@ void RKWardMainWindow::initActions()
 
 	fileOpenRecent = static_cast<KRecentFilesAction*> (actionCollection ()->addAction (KStandardAction::OpenRecent, "file_open_recenty", this, SLOT(slotOpenCommandEditor (const KUrl&))));
 
+#ifdef Q_WS_WIN
+	// TODO: find the cause and fix it! http://sourceforge.net/tracker/?func=detail&aid=2848341&group_id=50231&atid=459007
+#	warning TODO: import data dialog is disabled on windows due to bug in kdelibs
+#else
 	action = actionCollection ()->addAction ("import_data", this, SLOT (importData()));
 	action->setText (i18n ("Import Data"));
 	action->setStatusTip (i18n ("Import data from a variety of file formats"));
+#endif
 
 	fileOpenWorkspace = actionCollection ()->addAction (KStandardAction::Open, "file_openx", this, SLOT(slotFileOpenWorkspace()));
 	fileOpenWorkspace->setText (i18n ("Open Workspace"));
@@ -396,11 +404,11 @@ void RKWardMainWindow::partChanged (KParts::Part *part) {
 	}
 
 	QMenu* menu = dynamic_cast<QMenu*>(guiFactory ()->container ("edit", this));
-	edit_menu_dummy->setVisible (menu && (menu->actions ().size () <= 1));
+	edit_menu_dummy->setVisible (menu && (menu->isEmpty ()));
 	menu = dynamic_cast<QMenu*>(guiFactory ()->container ("view", this));
-	view_menu_dummy->setVisible (menu && (menu->actions ().size () <= 1));
+	view_menu_dummy->setVisible (menu && (menu->isEmpty ()));
 	menu = dynamic_cast<QMenu*>(guiFactory ()->container ("run", this));
-	run_menu_dummy->setVisible (menu && (menu->actions ().size () <= 1));
+	run_menu_dummy->setVisible (menu && (menu->isEmpty ()));
 }
 
 void RKWardMainWindow::initStatusBar () {
@@ -424,7 +432,6 @@ void RKWardMainWindow::openWorkspace (const KUrl &url) {
 	if (url.isEmpty ()) return;
 
 	new RKLoadAgent (url, false);
-	fileOpenRecentWorkspace->addUrl (url);
 }
 
 void RKWardMainWindow::saveOptions () {
@@ -583,6 +590,13 @@ void RKWardMainWindow::slotFileSaveWorkspaceAs () {
 	new RKSaveAgent (RObjectList::getObjectList ()->getWorkspaceURL (), true);
 }
 
+void RKWardMainWindow::addWorkspaceUrl (const KUrl &url) {
+	RK_TRACE (APP);
+
+	if (!url.isEmpty ()) fileOpenRecentWorkspace->addUrl (url);
+	setCaption (QString::null);	// trigger update of caption
+}
+
 void RKWardMainWindow::updateCWD () {
 	RK_TRACE (APP);
 
@@ -658,28 +672,32 @@ void RKWardMainWindow::slotNewCommandEditor () {
 	slotOpenCommandEditor (KUrl ());
 }
 
-void RKWardMainWindow::slotOpenCommandEditor (const KUrl &url) {
+void RKWardMainWindow::addScriptUrl (const KUrl& url) {
 	RK_TRACE (APP);
 
-	if (RKWorkplace::mainWorkplace ()->openScriptEditor (url)) {
-		if (!url.isEmpty ()) fileOpenRecent->addUrl (url);
-	}
-};
+	if (!url.isEmpty ()) fileOpenRecent->addUrl (url);
+}
+
+void RKWardMainWindow::slotOpenCommandEditor (const KUrl &url, const QString &encoding) {
+	RK_TRACE (APP);
+
+	RKWorkplace::mainWorkplace ()->openScriptEditor (url, encoding);
+}
 
 void RKWardMainWindow::slotOpenCommandEditor () {
 	RK_TRACE (APP);
-	KUrl::List urls;
+	KEncodingFileDialog::Result res;
 	KUrl::List::const_iterator it;
 
 #ifdef Q_WS_WIN
 	// getOpenUrls(KUrl("kfiledialog:///<rfiles>"), ...) causes a hang on windows (KDElibs 4.2.3).
 #	warning Track this bug down and/or report it
-	urls = KFileDialog::getOpenUrls (KUrl (), "*.R *.r *.S *.s *.q|R Script Files (*.R *.r *.S *.s *.q)\n*.*|All Files (*.*)", this, i18n ("Open command file(s)"));
+	res = KEncodingFileDialog::getOpenUrlsAndEncoding (QString (), QString (), "*.R *.r *.S *.s *.q|R Script Files (*.R *.r *.S *.s *.q)\n*|All Files (*)", this, i18n ("Open script file(s)"));
 #else
-	urls = KFileDialog::getOpenUrls (KUrl ("kfiledialog:///<rfiles>"), "*.R *.r *.S *.s *.q|R Script Files (*.R *.r *.S *.s *.q)\n*.*|All Files (*.*)", this, i18n ("Open command file(s)"));
+	res = KEncodingFileDialog::getOpenUrlsAndEncoding (QString (), "kfiledialog:///<rfiles>", "*.R *.r *.S *.s *.q|R Script Files (*.R *.r *.S *.s *.q)\n*|All Files (*)", this, i18n ("Open script file(s)"));
 #endif
-	for (it = urls.begin() ; it != urls.end() ; ++it) {
-		slotOpenCommandEditor (*it);
+	for (it = res.URLs.begin() ; it != res.URLs.end() ; ++it) {
+		slotOpenCommandEditor (*it, res.encoding);
 	}
 };
 
