@@ -19,19 +19,44 @@
 
 #include "windows/rkmdiwindow.h"
 
-#include <X11/X.h>
-#include <X11/Xlib.h>
+#ifdef Q_WS_WIN
+#	include <windows.h>
+#else
+#	include <X11/X.h>
+#	include <X11/Xlib.h>
 
-#include <QX11Info>
+#	include <QX11Info>
 
-#include <kwindowinfo.h>
-#include <netwm_def.h>
+#	include <kwindowinfo.h>
+#	include <netwm_def.h>
+//static
+Atom wm_name_property;
+#endif	//Q_WS_WIN
 
 #include "debug.h"
 
+#warning TODO: We could really use the detection logic from windows for x11, too. It seems much easier.
+#ifdef Q_WS_WIN
+#include <stdio.h>
+namespace RKWardApplicationPrivate {
+	QList<WId> toplevel_windows;
+
+	BOOL CALLBACK EnumWindowsCallback (HWND hwnd, LPARAM) {
+		toplevel_windows.append (hwnd);
+		return true;
+	}
+
+	void updateToplevelWindowList () {
+		RK_TRACE (APP);
+
+		toplevel_windows.clear ();
+		EnumWindows (EnumWindowsCallback, 0);
+	};
+}
+#endif	//Q_WS_WIN
+
 //static
 RKWardApplication *RKWardApplication::rkapp = 0;
-Atom wm_name_property;
 
 RKWardApplication::RKWardApplication () : KApplication () {
 	//RK_TRACE (APP);	// would be called before initialization of debug-level
@@ -40,7 +65,9 @@ RKWardApplication::RKWardApplication () : KApplication () {
 	rkapp = this;
 	detect_x11_creations = false;
 
+#ifndef Q_WS_WIN
 	wm_name_property = XInternAtom (QX11Info::display (), "WM_NAME", true);
+#endif	//nQ_WS_WIN
 }
 
 RKWardApplication::~RKWardApplication () {
@@ -60,14 +87,49 @@ void RKWardApplication::startWindowCreationDetection () {
 	created_window = 0;
 	detect_x11_creations = true;
 
+#ifdef Q_WS_WIN
+	RKWardApplicationPrivate::updateToplevelWindowList ();
+#else	//Q_WS_WIN
 	XSelectInput (QX11Info::display (), QX11Info::appRootWindow (), SubstructureNotifyMask);
 	syncX ();	// this is to make sure we don't miss out on the window creation (if it happens very early). Testing shows, we really need this.
+#endif	//Q_WS_WIN
 }
 
 WId RKWardApplication::endWindowCreationDetection () {
 	RK_TRACE (APP);
 	RK_ASSERT (detect_x11_creations);
 
+#ifdef Q_WS_WIN
+	QList<WId> old_windows = RKWardApplicationPrivate::toplevel_windows;
+	RKWardApplicationPrivate::updateToplevelWindowList ();
+	QList<WId> candidate_windows = RKWardApplicationPrivate::toplevel_windows;
+
+	detect_x11_creations = false;
+
+	// remove all windows that existed before the call to startWindowCreationDetection
+	for (int i = 0; i < old_windows.size (); ++i) {
+		candidate_windows.removeAll (old_windows[i]);
+	}
+	// ideally we have a single candidate remaining, now, but sometimes, additional
+	// invisible windows are created somehow (probably by R's graphapp)
+	for (int i = 0; i < candidate_windows.size (); ++i) {
+		HWND hwnd = candidate_windows[i];
+		if ((!IsWindow(hwnd)) || (!IsWindowVisible(hwnd))) {
+			 candidate_windows.removeAt (i);
+			 --i;
+		}
+	}
+
+	// we could do some more checking, e.g. based on whether the window belongs to our
+	// own process, and whether it appears to be of a sane size, but for now, we keep
+	// things simple.
+
+	if (candidate_windows.size ()) {
+		RK_ASSERT (candidate_windows.size () < 2);
+		return candidate_windows[0];
+	}
+	return 0;
+#else	//Q_WS_WIN
 	if (!created_window) {
 		// we did not see the window, yet? Maybe the event simply hasn't been processed, yet.
 		syncX ();
@@ -77,8 +139,10 @@ WId RKWardApplication::endWindowCreationDetection () {
 	detect_x11_creations = false;
 	XSelectInput (QX11Info::display (), QX11Info::appRootWindow (), NoEventMask);
 	return created_window;
+#endif	//Q_WS_WIN
 }
 
+#ifndef Q_WS_WIN
 void RKWardApplication::registerNameWatcher (WId watched, RKMDIWindow *watcher) {
 	RK_TRACE (APP);
 	RK_ASSERT (!name_watchers_list.contains (watched));
@@ -100,8 +164,9 @@ bool RKWardApplication::x11EventFilter (XEvent *e) {
 		if (e->type == CreateNotify) {
 			if (e->xcreatewindow.parent == QX11Info::appRootWindow ()) {
 				KWindowInfo info = KWindowInfo (e->xcreatewindow.window, NET::WMName | NET::WMWindowType);
-				if ((info.windowType (0xFFFF) != 0) && (!info.name ().isEmpty ())) {
-					RK_ASSERT (!created_window);
+				// at this point, we used to check, whether this window has some name or another. This heuristic allowed to sieve out helper windows of the window manager. However, since R 2.8.0, sometimes the window is mapped, before it has been given a name.
+				// Now we rely on the fact (we hope it *is* a fact), that the device window is always the first one created.
+				if ((info.windowType (0xFFFF) != 0) && (!created_window)) {
 					created_window = e->xcreatewindow.window;
 					return true;
 				}
@@ -123,4 +188,4 @@ bool RKWardApplication::x11EventFilter (XEvent *e) {
 
 	return KApplication::x11EventFilter (e);
 }
-
+#endif	//nQ_WS_WIN
