@@ -2,7 +2,7 @@
                           robjectviewer  -  description
                              -------------------
     begin                : Tue Aug 24 2004
-    copyright            : (C) 2004, 2007 by Thomas Friedrichsmeier
+    copyright            : (C) 2004, 2007, 2009 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -126,8 +126,8 @@ void RObjectViewer::initDescription (bool notify) {
 	if (!_object) return;
 
 	setCaption (i18n("Object Viewer: %1", _object->getShortName ()));
-	// TODO: what an ugly hack... This should be the job of RObject::getObjectDescription().
-	description_label->setText ("<nobr>" + _object->getObjectDescription ().replace ("<br>", "&nbsp; -</nobr> &nbsp;<nobr>") + "</nobr>");
+	// make the description use less height. Trying to specify <nobr>s, here, is no good idea (see https://sourceforge.net/tracker/?func=detail&atid=459007&aid=2859182&group_id=50231)
+	description_label->setText (_object->getObjectDescription ().replace ("<br>", "&nbsp; &nbsp; "));
 	if (notify) {
 		QString reason = i18n ("The object was changed. You may want to click \"Update\"");
 		summary_widget->invalidate (reason);
