@@ -4,11 +4,13 @@ function echo (text) {
 }
 
 function printIndented (indentation, lines) {
-	echo (indentation + lines.replace (/\n/g, "\n" + indentation));
+	/** More complex than may seem necessary at first glance. The point is that the
+	final linebreak in the input should *not* be replaced by linebreak + indentation. */
+	echo (indentation + lines.replace (/\n(.)/g, "\n" + indentation + "$1"));
 }
 
 function noquote (text) {
-	ret = new String (text);
+	var ret = new String (text);
 	ret.noquote = 1;
 	return (ret);
 }
@@ -24,8 +26,8 @@ function makeHeaderCode (title, parameters) {
 		echo (", parameters=list(");
 		for (var p = 0; p < parameters.length; ++p) {
 			if (p) {
-				echo (", ");
-				if (!(p % 2)) echo ("\n\t");
+				if (!(p % 2)) echo (",\n\t");
+				else echo (", ");
 			}
 			echo (quote(parameters[p]));
 		}
@@ -82,6 +84,10 @@ function trim (text) {
 	return (ret);
 }
 
+function split (by, text) {
+	return (text.split (by));
+}
+
 function str_replace (needle, replacement, haystack) {
 	return (haystack.split (needle).join (replacement));
 }
