@@ -20,6 +20,25 @@ function getPreview () {
 	}
 }
 
+function makeHeaderCode ($title, $parameters=array ()) {
+	echo ("rk.header(" . quote ($title));
+	if (!empty ($parameters)) {
+		echo (", parameters=list(");
+		$first = true;
+		foreach ($parameters as $key => $value) {
+			if ($first) $first = false;
+			else echo (",\n\t");
+			echo (quote($key) . ', ' . quote ($value));
+		}
+		echo (")");
+	}
+	echo (")\n");
+}
+
+function quote ($input) {
+	return ('"' . str_replace ("\"", "\\\"", $input) . '"');
+}
+
 function getInput ($prompt) {
 	fputs (STDOUT, "#RKEND#\n" . $prompt . "#RKQEND#\n");
 	fflush (STDOUT);
