@@ -21,10 +21,8 @@
 
 #include <qstring.h>
 #include <qobject.h>
-#include <kprocess.h>
+#include <QProcess>
 #include <qstringlist.h>
-#include <qvaluelist.h>
-#include <ktempfile.h>
 
 class RKPlugin;
 
@@ -49,25 +47,20 @@ public:
 	void preview (int flags) { callFunction ("getPreview ();", flags, Preview); };
 	void writeData (const QString &data);
 public slots:
-	void gotOutput (KProcess *proc, char* buf, int len);
-	//void gotError (KProcess *proc, char* buf, int len);
-	void processDied (KProcess *proc);
-	void doneWriting (KProcess *proc);
+	void gotOutput ();
+	void processError (QProcess::ProcessError error);
+	void processDead (int exitCode, QProcess::ExitStatus exitStatus);
 private:
 	void tryNextFunction ();
-	void tryWriteData ();
-	KProcess *php_process;
+	QProcess *php_process;
 /// The string singalling the end of transmission to/from PHP. TODO: make static
 	QString eot_string;
 /// The string singalling the end of request from PHP. TODO: make static
 	QString eoq_string;
-/** actually only one piece of data gets requested at a time. However, sometimes it takes a while until we realize (via doneWriting ()) that the last piece was transmitted ok (we have to keep a write buffer until then). So it may happen, that a new piece of information was requested, before we have completed the process for the previous one. Hence we use a FIFO stack just like for the commands (though it's handled slightly differently). */
-	QStringList data_stack;
-/// write buffer for the current command
-	QString current_command;
-	bool busy_writing;
+
 	bool doing_command;
 	bool startup_done;
+	bool dead;
 	QString output_raw_buffer;
 
 	QString _output;
