@@ -17,9 +17,9 @@
 #ifndef RKSETTINGS_H
 #define RKSETTINGS_H
 
-#include <kdialogbase.h>
+#include <kpagedialog.h>
 
-#include <qvaluelist.h>
+#include <qmap.h>
 
 class RKSettingsModule;
 class KConfig;
@@ -32,10 +32,24 @@ The main settings-dialog. Contains subsections (tabs) for different modules. Use
 
 @author Thomas Friedrichsmeier
 */
-class RKSettings : public KDialogBase {
+class RKSettings : public KPageDialog {
 	Q_OBJECT
 public:
-	enum SettingsPage { NoPage=0, Plugins=1, R=2, RPackages=3, PHP=4, General=5, Output=6, Watch=7, Console=8, ObjectBrowser=9 };
+	enum SettingsPage {
+		NoPage=0,
+		PagePlugins=1,
+		PageR=2,
+		PageRPackages=3,
+		PagePHP=4,
+		PageGeneral=5,
+		PageOutput=6,
+		PageWatch=7,
+		PageConsole=8,
+		PageCommandEditor=9,
+		PageObjectBrowser=10,
+		PageDebug=11,
+		NumPages = PageDebug + 1
+	};
 
 	static void configureSettings (SettingsPage page=NoPage, QWidget *parent=0, RCommandChain *chain=0);
 
@@ -46,23 +60,22 @@ public:
 	
 	static RKSettingsTracker* tracker () { return settings_tracker; };
 public slots:
-	void pageAboutToBeShown (QWidget *page);
+	void pageChange (KPageWidgetItem *current, KPageWidgetItem *before);
 protected:
-	void slotApply ();
-	void slotOk ();
-	void slotCancel ();
-	void slotHelp ();
+	void slotButtonClicked (int button);
 protected:
-	RKSettings (QWidget *parent = 0, const char *name = 0);
+	RKSettings (QWidget *parent = 0);
 	~RKSettings ();
 private:
+	void applyAll ();
 	void initModules ();
 	void raisePage (SettingsPage page);
 	static void dialogClosed ();
-	
-	typedef QValueList<RKSettingsModule *> ModuleList;
-	ModuleList modules;
-	
+
+	typedef QMap<SettingsPage, RKSettingsModule *> ModuleMap;
+	ModuleMap modules;
+	KPageWidgetItem *pages[NumPages];
+
 	static RKSettings *settings_dialog;
 friend class RKWardMainWindow;
 	static RKSettingsTracker *settings_tracker;
@@ -76,9 +89,9 @@ public:
 	RKSettingsTracker (QObject *parent);
 	~RKSettingsTracker ();
 
-	void settingsChangedObjectBrowser ();
+	void signalSettingsChange (RKSettings::SettingsPage page);
 signals:
-	void objectBrowserSettingsChanged ();
+	void settingsChanged (RKSettings::SettingsPage);
 };
 
 #endif
