@@ -2,7 +2,7 @@
                           rksettingsmoduler  -  description
                              -------------------
     begin                : Wed Jul 28 2004
-    copyright            : (C) 2004, 2007, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2004, 2007, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -29,8 +29,11 @@
 #include <qlineedit.h>
 #include <QVBoxLayout>
 #include <QGridLayout>
+#include <QPushButton>
 
+#include "../core/robject.h"
 #include "../misc/multistringselector.h"
+#include "../misc/rkprogresscontrol.h"
 #include "../rbackend/rinterface.h"
 #include "../rkglobals.h"
 #include "../debug.h"
@@ -260,7 +263,7 @@ QStringList RKSettingsModuleR::makeRRunTimeOptionCommands () {
 	// register as interactive
 	list.append ("try (deviceIsInteractive(name=\"rk.screen.device\"))\n");
 	list.append ("options (help_type=\"html\")\n");		// for R 2.10.0 and above
-	list.append ("options (htmlhelp=TRUE); options (chmhelp=FALSE)\n");	// COMPAT: for R 2.9.x and below
+	list.append ("try ({options (htmlhelp=TRUE); options (chmhelp=FALSE)})\n");	// COMPAT: for R 2.9.x and below
 	list.append ("options (browser=rk.show.html)\n");
 
 	return list;
@@ -320,30 +323,42 @@ QStringList RKSettingsModuleRPackages::defaultliblocs;
 bool RKSettingsModuleRPackages::archive_packages;
 QStringList RKSettingsModuleRPackages::package_repositories;
 QString RKSettingsModuleRPackages::essential_packages = QString ("base\nmethods\nutils\ngrDevices\ngraphics\nrkward");
+QString RKSettingsModuleRPackages::cran_mirror_url;
 
-RKSettingsModuleRPackages::RKSettingsModuleRPackages (RKSettings *gui, QWidget *parent) : RKSettingsModule(gui, parent) {
+RKSettingsModuleRPackages::RKSettingsModuleRPackages (RKSettings *gui, QWidget *parent) : RKSettingsModule(gui, parent), RCommandReceiver () {
 	RK_TRACE (SETTINGS);
 
 	QVBoxLayout *main_vbox = new QVBoxLayout (this);
 
 	main_vbox->addSpacing (2*RKGlobals::spacingHint ());
 
-	repository_selector = new MultiStringSelector (i18n ("Package repositories (where libraries are downloaded from)"), this);
+	main_vbox->addWidget (new QLabel (i18n ("CRAN download mirror (leave empty to be prompted once each session):"), this));
+	QHBoxLayout* hbox = new QHBoxLayout ();
+	main_vbox->addLayout (hbox);
+	cran_mirror_input = new QLineEdit (cran_mirror_url, this);
+	if (cran_mirror_url == "@CRAN@") cran_mirror_input->clear ();
+	connect (cran_mirror_input, SIGNAL (textChanged(const QString&)), this, SLOT (settingChanged()));
+	hbox->addWidget (cran_mirror_input);
+	QPushButton* cran_mirror_button = new QPushButton (i18n ("Select mirror"), this);
+	connect (cran_mirror_button, SIGNAL (clicked()), this, SLOT (selectCRANMirror()));
+	hbox->addWidget (cran_mirror_button);
+
+	repository_selector = new MultiStringSelector (i18n ("Additional package repositories (where libraries are downloaded from)"), this);
 	repository_selector->setValues (package_repositories);
-	connect (repository_selector, SIGNAL (listChanged ()), this, SLOT (listChanged ()));
+	connect (repository_selector, SIGNAL (listChanged ()), this, SLOT (settingChanged ()));
 	connect (repository_selector, SIGNAL (getNewStrings (QStringList*)), this, SLOT (addRepository (QStringList*)));
 	main_vbox->addWidget (repository_selector);
 
 	archive_packages_box = new QCheckBox (i18n ("Archive downloaded packages"), this);
 	archive_packages_box->setChecked (archive_packages);
-	connect (archive_packages_box, SIGNAL (stateChanged (int)), this, SLOT (boxChanged (int)));
+	connect (archive_packages_box, SIGNAL (stateChanged (int)), this, SLOT (settingChanged()));
 	main_vbox->addWidget (archive_packages_box);	
 
 	main_vbox->addStretch ();
 
-	libloc_selector = new MultiStringSelector (i18n ("R Library locations  (where libraries get installed to, locally)"), this);
+	libloc_selector = new MultiStringSelector (i18n ("R Library locations (where libraries get installed to, locally)"), this);
 	libloc_selector->setValues (liblocs);
-	connect (libloc_selector, SIGNAL (listChanged ()), this, SLOT (listChanged ()));
+	connect (libloc_selector, SIGNAL (listChanged ()), this, SLOT (settingChanged ()));
 	connect (libloc_selector, SIGNAL (getNewStrings (QStringList*)), this, SLOT (addLibLoc (QStringList*)));
 	main_vbox->addWidget (libloc_selector);
 	QLabel *label = new QLabel (i18n ("Note: The startup defaults will always be used in addition to the locations you specify in this list"), this);
@@ -356,12 +371,7 @@ RKSettingsModuleRPackages::~RKSettingsModuleRPackages () {
 	RK_TRACE (SETTINGS);
 }
 
-void RKSettingsModuleRPackages::listChanged () {
-	RK_TRACE (SETTINGS);
-	change ();
-}
-
-void RKSettingsModuleRPackages::boxChanged (int) {
+void RKSettingsModuleRPackages::settingChanged () {
 	RK_TRACE (SETTINGS);
 	change ();
 }
@@ -376,7 +386,7 @@ void RKSettingsModuleRPackages::addLibLoc (QStringList *string_list) {
 
 void RKSettingsModuleRPackages::addRepository (QStringList *string_list) {
 	RK_TRACE (SETTINGS);
-	QString new_string = KInputDialog::getText (i18n ("Add repository"), i18n ("Add URL of new repository\n(Enter \"@CRAN@\" for the standard CRAN-mirror)"), QString::null, 0, this);
+	QString new_string = KInputDialog::getText (i18n ("Add repository"), i18n ("Add URL of new repository"), QString::null, 0, this);
 	(*string_list).append (new_string);
 }
 
@@ -390,18 +400,40 @@ bool RKSettingsModuleRPackages::hasChanges () {
 	return changed;
 }
 
+#define SELECT_CRAN_MIRROR_COMMAND 123
+void RKSettingsModuleRPackages::selectCRANMirror () {
+	RK_TRACE (SETTINGS);
+	QString title = i18n ("Select CRAN mirror");
+	
+	RCommand* command = new RCommand ("rk.select.CRAN.mirror()\n", RCommand::App | RCommand::GetStringVector, title, this, SELECT_CRAN_MIRROR_COMMAND);
+
+	RKProgressControl* control = new RKProgressControl (this, title, title, RKProgressControl::StandardCancel);
+	control->addRCommand (command, true);
+	RKGlobals::rInterface ()->issueCommand (command);
+	control->doModal (true);
+}
+
+void RKSettingsModuleRPackages::rCommandDone (RCommand *command) {
+	RK_TRACE (SETTINGS);
+
+	if (command->getFlags () == SELECT_CRAN_MIRROR_COMMAND) {
+		if (command->succeeded ()) {
+			RK_ASSERT (command->getStringVector ());
+			cran_mirror_input->setText (command->getStringVector ()[0]);
+		}
+	} else {
+		RK_ASSERT (false);
+	}
+}
+
 //static
 QStringList RKSettingsModuleRPackages::makeRRunTimeOptionCommands () {
 	QStringList list;
 
 // package repositories
-	QString command = "options (repos=c (";
+	QString command = "options (repos=c (CRAN=" + RObject::rQuote (cran_mirror_url);
 	for (QStringList::const_iterator it = package_repositories.begin (); it != package_repositories.end (); ++it) {
-		if (it != package_repositories.begin ()) {
-			command.append (", ");
-		}
-		if (*it == "@CRAN@") command.append ("CRAN="); 
-		command.append ("\"" + *it + "\"");
+		command.append (", " + RObject::rQuote (*it));
 	}
 	list.append (command + "))\n");
 
@@ -427,6 +459,9 @@ QStringList RKSettingsModuleRPackages::makeRRunTimeOptionCommands () {
 void RKSettingsModuleRPackages::applyChanges () {
 	RK_TRACE (SETTINGS);
 
+	cran_mirror_url = cran_mirror_input->text ();
+	if (cran_mirror_url.isEmpty ()) cran_mirror_url = "@CRAN@";
+
 	archive_packages = archive_packages_box->isChecked ();
 	package_repositories = repository_selector->getValues ();
 	liblocs = libloc_selector->getValues ();
@@ -448,6 +483,7 @@ void RKSettingsModuleRPackages::saveSettings (KConfig *config) {
 	RK_TRACE (SETTINGS);
 
 	KConfigGroup cg = config->group ("R Settings");
+	cg.writeEntry ("CRAN mirror url", cran_mirror_url);
 	cg.writeEntry ("archive packages", archive_packages);
 	cg.writeEntry ("Repositories", package_repositories);
 	cg.writeEntry ("LibraryLocations", liblocs);
@@ -457,10 +493,13 @@ void RKSettingsModuleRPackages::loadSettings (KConfig *config) {
 	RK_TRACE (SETTINGS);
 
 	KConfigGroup cg = config->group ("R Settings");
-	archive_packages = cg.readEntry ("archive packages", false);
-	package_repositories = cg.readEntry ("Repositories", QStringList ("@CRAN@"));
+
+	cran_mirror_url = cg.readEntry ("CRAN mirror url", "@CRAN@");
+	package_repositories = cg.readEntry ("Repositories", QStringList ());
+	package_repositories.removeAll ("@CRAN@");	// COMPAT: Cran mirror was part of this list before 0.5.3
 
 	liblocs = cg.readEntry ("LibraryLocations", QStringList ());
+	archive_packages = cg.readEntry ("archive packages", false);
 }
 
 #include "rksettingsmoduler.moc"
