@@ -2,7 +2,7 @@
                           rkcommandeditorwindow  -  description
                              -------------------
     begin                : Mon Aug 30 2004
-    copyright            : (C) 2004, 2006, 2007, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2004, 2006, 2007, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -157,12 +157,14 @@ void RKCommandEditorWindow::fixupPartGUI () {
 void RKCommandEditorWindow::initializeActions (KActionCollection* ac) {
 	RK_TRACE (COMMANDEDITOR);
 
-	action_run_all = RKStandardActions::runAll (this, "run_all", this, SLOT (runAll()));
-	action_run_selection = RKStandardActions::runSelection (this, "run_selection", this, SLOT (runSelection()));
-	action_run_selection->setEnabled (false);
-	action_run_line = RKStandardActions::runLine (this, "run_line", this, SLOT (runLine()));
+	RKStandardActions::pasteSpecial (this, this, SLOT (paste(const QString&)));
 
-	action_help_function = RKStandardActions::functionHelp (this, "function_reference", this, SLOT (showHelp()));
+	action_run_all = RKStandardActions::runAll (this, this, SLOT (runAll()));
+	action_run_selection = RKStandardActions::runSelection (this, this, SLOT (runSelection()));
+	action_run_selection->setEnabled (false);
+	action_run_line = RKStandardActions::runLine (this, this, SLOT (runLine()));
+
+	action_help_function = RKStandardActions::functionHelp (this, this, SLOT (showHelp()));
 
 	actionmenu_run_block = new KActionMenu (i18n ("Run block"), this);
 	actionmenu_run_block->setDelayed (false);	// KDE4: TODO does not work correctly in the tool bar.
@@ -253,6 +255,8 @@ void RKCommandEditorWindow::focusIn (KTextEditor::View* v) {
 	setPopupMenu ();
 }
 
+/** NOTE: this function still needed?
+- Still needed in KDE 4.3.4. */
 void RKCommandEditorWindow::setPopupMenu () {
 	RK_TRACE (COMMANDEDITOR);
 
@@ -311,8 +315,11 @@ void RKCommandEditorWindow::setReadOnly (bool ro) {
 	m_doc->setReadWrite (!ro);
 }
 
-bool RKCommandEditorWindow::openURL (const KUrl &url, bool use_r_highlighting, bool read_only){
+bool RKCommandEditorWindow::openURL (const KUrl &url, const QString& encoding, bool use_r_highlighting, bool read_only){
 	RK_TRACE (COMMANDEDITOR);
+
+	// encoding must be set *before* loading the file
+	if (!encoding.isEmpty ()) m_doc->setEncoding (encoding);
 	if (m_doc->openUrl (url)){
 		if (use_r_highlighting) setRHighlighting ();
 		setReadOnly (read_only);
@@ -355,8 +362,9 @@ void RKCommandEditorWindow::updateCaption (KTextEditor::Document*) {
 
 	setCaption (name);
 
-	// Well, this does not really belong, here, but needs to happen on pretty much the same occastions:
+	// Well, these do not really belong, here, but need to happen on pretty much the same occasions:
 	action_setwd_to_script->setEnabled (!url ().isEmpty ());
+	RKWardMainWindow::getMain ()->addScriptUrl (url ());
 }
 
 void RKCommandEditorWindow::showHelp () {
@@ -442,6 +450,12 @@ bool RKCommandEditorWindow::provideContext (unsigned int line_rev, QString *cont
 	return true;
 }
 
+void RKCommandEditorWindow::paste (const QString& text) {
+	RK_TRACE (COMMANDEDITOR);
+
+	m_view->insertText (text);
+}
+
 void RKCommandEditorWindow::setWDToScript () {
 	RK_TRACE (COMMANDEDITOR);
 
