@@ -40,7 +40,7 @@
 #include "../misc/rkcommonfunctions.h"
 #include "../misc/rkdummypart.h"
 
-#define GET_HELP_URL 1
+#define GET_HELP 1
 #define HELP_SEARCH 2
 #define GET_INSTALLED_PACKAGES 3
 
@@ -152,15 +152,12 @@ void RKHelpSearchWindow::getContextHelp (const QString &context_line, int cursor
 void RKHelpSearchWindow::getFunctionHelp (const QString &function_name, const QString &package) {
 	RK_TRACE (APP);
 
-	QString command = "help(\"" + function_name + '\"';
+	// we use .rk.getHelp() instead of plain help() to receive an error, if no help could be found
+	QString command = ".rk.getHelp(\"" + function_name + '\"';
 	if (!package.isEmpty ()) command.append (", package=" + package);
-	command.append (", chmhelp=FALSE, htmlhelp=TRUE)[1]");
+	command.append (")");
 
-	RKGlobals::rInterface ()->issueCommand (command, RCommand::App | RCommand::GetStringVector, i18n ("Find HTML help for %1").arg (function_name), this, GET_HELP_URL);
-
-	// we *could* simply call show() on the object that help() returns. However, since this function
-	// may be called externally, we need to handle the case when no help can be found. So we use
-	// this two-stage approach, instead.
+	RKGlobals::rInterface ()->issueCommand (command, RCommand::App | RCommand::GetStringVector, i18n ("Find HTML help for %1").arg (function_name), this, GET_HELP);
 }
 
 void RKHelpSearchWindow::slotFindButtonClicked () {
@@ -218,17 +215,8 @@ void RKHelpSearchWindow::rCommandDone (RCommand *command) {
 
 		for (int i = 0; i < COL_COUNT; ++i) results_view->resizeColumnToContents (i);
 		setEnabled(true);
-	} else if (command->getFlags () == GET_HELP_URL) {
-		KUrl url;
-
-		if (command->getDataLength ()) {
-			RK_ASSERT (command->getDataType () == RData::StringVector);
-			url.setPath(command->getStringVector ()[0]);
-		}
-		if (QFile::exists (url.path ())) {
-			RKWardMainWindow::getMain ()->openHTML (url);
-			return;
-		} else {
+	} else if (command->getFlags () == GET_HELP) {
+		if (command->failed ()) {
 			KMessageBox::sorry (this, i18n ("No help found on '%1'. Maybe the corresponding package is not installed/loaded, or maybe you mistyped the command. Try using Help->Search R Help for more options.", command->command ().section ("\"", 1, 1)), i18n ("No help found"));
 		}
 	} else if (command->getFlags () == GET_INSTALLED_PACKAGES) {
