@@ -2,7 +2,7 @@
                           rkhtmlwindow  -  description
                              -------------------
     begin                : Wed Oct 12 2005
-    copyright            : (C) 2005, 2006, 2007, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2005, 2006, 2007, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -36,6 +36,7 @@
 #include <QHostInfo>
 
 #include "../rkglobals.h"
+#include "../rbackend/rinterface.h"
 #include "rkhelpsearchwindow.h"
 #include "../rkward.h"
 #include "../rkconsole.h"
@@ -121,7 +122,7 @@ void RKHTMLWindow::initActions () {
 
 	print = actionCollection ()->addAction (KStandardAction::Print, "print_html", this, SLOT (slotPrint()));
 
-	run_selection = RKStandardActions::runSelection (this, "run_selection", this, SLOT (runSelection()));
+	run_selection = RKStandardActions::runSelection (this, this, SLOT (runSelection()));
 
 		// needed to enable / disable the run selection action
 	connect (khtmlpart, SIGNAL (selectionChanged()), this, SLOT (selectionChanged()));
@@ -397,7 +398,7 @@ void RKHTMLWindow::fileDoesNotExistMessage () {
 
 	khtmlpart->begin();
 	if (window_mode == HTMLOutputWindow) {
-		khtmlpart->write (i18n ("<HTML><BODY><H1>RKWard output</H1>\n<P>The output is empty.</P>\n</BODY></HTML>"));
+		khtmlpart->write (i18n ("<HTML><BODY><H1>RKWard output file could not be found</H1>\n</BODY></HTML>"));
 	} else {
 		khtmlpart->write ("<html><body><h1>" + i18n ("Page does not exist or is broken") + "</h1></body></html>");
 	}
@@ -420,6 +421,9 @@ void RKHTMLWindow::flushOutput () {
 			QFile file (out_dir.absoluteFilePath (*it));
 			file.remove ();
 		}
+
+		// initialize the now empty file
+		RKGlobals::rInterface ()->issueCommand ("rk.set.output.html.file (\"" + out_file.fileName () + "\")\n", RCommand::App);
 		refresh ();
 	}
 }
@@ -448,7 +452,7 @@ bool RKHTMLWindow::renderRKHelp (const KUrl &url) {
 		QDomElement element;
 		QDomElement component_doc_element;
 		QString help_base_dir = RKCommonFunctions::getRKWardDataDir () + "pages/";
-		QString css_filename = "file://" + help_base_dir + "rkward_help.css";
+		QString css_filename = QUrl::fromLocalFile (help_base_dir + "rkward_help.css").toString ();
 
 		// determine help file, and prepare
 		if (for_component) {
@@ -572,18 +576,14 @@ bool RKHTMLWindow::renderRKHelp (const KUrl &url) {
 
 		// create a navigation bar
 		KUrl url_copy = url;
-		QString navigation;
-		QStringList::const_iterator names_it = anchornames.constBegin ();
-		for (QStringList::const_iterator it = anchors.constBegin (); it != anchors.constEnd (); ++it) {
-			if (!((*it).isNull () || (*names_it).isNull ())) {
-				url_copy.setRef (*it);
-				navigation.append ("<p><a href=\"" + url_copy.url () + "\">" + *names_it + "</a></p>\n");
-			}
-
-			if (names_it != anchornames.constEnd ()) {
-				++names_it;
-			} else {
-				RK_ASSERT (false);
+		QString navigation = i18n ("<h1>On this page:</h1>");
+		RK_ASSERT (anchornames.size () == anchors.size ());
+		for (int i = 0; i < anchors.size (); ++i) {
+			QString anchor = anchors[i];
+			QString anchorname = anchornames[i];
+			if (!(anchor.isEmpty () || anchorname.isEmpty ())) {
+				url_copy.setRef (anchor);
+				navigation.append ("<p><a href=\"" + url_copy.url () + "\">" + anchorname + "</a></p>\n");
 			}
 		}
 		khtmlpart->write ("</div><div id=\"navigation\">" + navigation + "</div>");
