@@ -67,14 +67,7 @@ public:
 	KUrl url ();
 	void doGotoAnchor (const QString &anchor_name);
 
-/** return a pointer to the current output. If there is no output window, one will be created (and shown) automatically */
-	static RKHTMLWindow* getCurrentOutput ();
-/** refresh output window.
-@param show Show the window, if not currently shown (this actually means: it is created if not currently existant)
-@param raise Raise the window (if currently shown, or show==true) */
-	static RKHTMLWindow* refreshOutput (bool show, bool raise);
-/** reimplemented from RKMDIWindow */
-	void fixupPartGUI (bool reload);
+	WindowMode mode () { return window_mode; };
 public slots:
 /** this is used for browsing only. Use openURL instead, when calling from outside. */
 	void slotOpenUrl (const KUrl & url, const KParts::OpenUrlArguments &, const KParts::BrowserArguments &);
@@ -87,6 +80,8 @@ public slots:
 	void flushOutput ();
 /** Reload current page.*/
 	void refresh ();
+/** apply our customizations to the khtmlpart GUI */
+	void fixupPartGUI ();
 private slots:
 /** This slot is called when the new page has finished loading. Sets scroll position to scroll_position */
 	void loadDone ();
@@ -123,12 +118,11 @@ private:
 
 	void fileDoesNotExistMessage ();
 
-	static RKHTMLWindow *current_output;
-
 	// for dealing with rkward://[page|component]-pages
 	bool renderRKHelp (const KUrl &url);
 	QString renderHelpFragment (QDomElement &fragment);
 	void prepareHelpLink (QDomElement *link_element);
+	QString componentPathToId (QString path);
 	RKComponentHandle *componentPathToHandle (QString path);
 	QString startSection (const QString &name, const QString &title, const QString &shorttitle, QStringList *anchors, QStringList *anchor_names);
 
@@ -147,5 +141,32 @@ public:
 	~RKHelpRenderer () {};
 };
 
+#include <QMultiHash>
+
+#include <kdirwatch.h>
+
+/** Takes care of showing / refreshing output windows as needed. */
+class RKOutputWindowManager : public QObject {
+Q_OBJECT
+public:
+	static RKOutputWindowManager *self ();
+
+	void registerWindow (RKHTMLWindow *window);
+/** R may produce output while no output window is active. This allows to set the file that should be monitored for such changes (called from within rk.set.html.output.file()). */
+	void setCurrentOutputPath (const QString &path);
+/** return a pointer to the current output. If there is no output window, one will be created (and shown) automatically */
+	RKHTMLWindow* getCurrentOutputWindow ();
+private:
+	RKOutputWindowManager ();
+	~RKOutputWindowManager ();
+	static RKOutputWindowManager *_self;
+
+	QString current_default_path;
+	KDirWatch *file_watcher;
+	QMultiHash<QString, RKHTMLWindow *> windows;
+private slots:
+	void fileChanged (const QString &path);
+	void windowDestroyed (QObject *window);
+};
 
 #endif
