@@ -31,6 +31,7 @@
 #include "rktoolwindowbar.h"
 #include "../settings/rksettingsmodulegeneral.h"
 #include "../misc/rkstandardicons.h"
+#include "../misc/rkxmlguisyncer.h"
 
 #include "../debug.h"
 
@@ -81,20 +82,6 @@ KActionCollection *RKMDIWindow::standardActionCollection () {
 	return standard_client->actionCollection ();
 }
 
-void RKMDIWindow::fixupPartGUI (bool reload) {
-	RK_TRACE (APP);
-	RK_ASSERT (part);
-
-	if (reload) {
-		// needed esp. to apply changed shortcut settings
-		part->reloadXML ();
-		foreach (KXMLGUIClient *client, part->childClients ()) {
-			// no further recursion needed in our case
-			client->reloadXML ();
-		}
-	}
-}
-
 //virtual
 QString RKMDIWindow::fullCaption () {
 	RK_TRACE (APP);
@@ -141,7 +128,10 @@ void RKMDIWindow::activate (bool with_focus) {
 		topLevelWidget ()->activateWindow ();
 		setFocus();
 	} else {
-		if (old_focus) old_focus->setFocus ();
+		if (old_focus) {
+			old_focus->setFocus ();
+			active = false;
+		}
 	}
 }
 
@@ -221,6 +211,8 @@ void RKMDIWindow::initializeActivationSignals () {
 
 	RK_ASSERT (getPart ());
 	getPart ()->installEventFilter (this);
+
+	RKXMLGUISyncer::self ()->watchXMLGUIClientUIrc (getPart ());
 }
 
 void RKMDIWindow::paintEvent (QPaintEvent *e) {
