@@ -2,7 +2,7 @@
                           rkworkplace  -  description
                              -------------------
     begin                : Thu Sep 21 2006
-    copyright            : (C) 2006, 2007, 2009 by Thomas Friedrichsmeier
+    copyright            : (C) 2006, 2007, 2009, 2010 by Thomas Friedrichsmeier
     email                : tfry@users.sourceforge.net
  ***************************************************************************/
 
@@ -205,7 +205,7 @@ bool RKWorkplace::openAnyUrl (const KUrl &url) {
 		return true;	// TODO
 	}
 	if (mimetype->name ().startsWith ("text")) {
-		return (openScriptEditor (url, false));
+		return (openScriptEditor (url, QString (), false));
 	}
 
 	if (KMessageBox::questionYesNo (this, i18n ("The url you are trying to open ('%1') is not a local file or the filetype is not supported by RKWard. Do you want to open the url in the default application?", url.prettyUrl ()), i18n ("Open in default application?")) != KMessageBox::Yes) {
@@ -216,26 +216,25 @@ bool RKWorkplace::openAnyUrl (const KUrl &url) {
 	return false;
 }
 
-bool RKWorkplace::openScriptEditor (const KUrl &url, bool use_r_highlighting, bool read_only, const QString &force_caption) {
+bool RKWorkplace::openScriptEditor (const KUrl &url, const QString& encoding, bool use_r_highlighting, bool read_only, const QString &force_caption) {
 	RK_TRACE (APP);
 
 // is this url already opened?
 	if (!url.isEmpty ()) {
-		for (RKWorkplaceObjectList::const_iterator it = windows.constBegin (); it != windows.constEnd (); ++it) {
-			if ((*it)->type == RKMDIWindow::CommandEditorWindow) {
-				KUrl ourl = static_cast<RKCommandEditorWindow *> (*it)->url ();
-				if (url == ourl) {
-					(*it)->activate ();
-					return true;
-				}
-			}
+	  	RKWorkplaceObjectList script_windows = getObjectList (RKMDIWindow::CommandEditorWindow, RKMDIWindow::AnyWindowState);
+		for (RKWorkplaceObjectList::const_iterator it = script_windows.constBegin (); it != script_windows.constEnd (); ++it) {
+			  KUrl ourl = static_cast<RKCommandEditorWindow *> (*it)->url ();
+			  if (url == ourl) {
+				  (*it)->activate ();
+				  return true;
+			  }
 		}
 	}
 
 	RKCommandEditorWindow *editor = new RKCommandEditorWindow (view (), use_r_highlighting);
 
 	if (!url.isEmpty ()) {
-		if (!editor->openURL (url, use_r_highlighting, read_only)) {
+		if (!editor->openURL (url, encoding, use_r_highlighting, read_only)) {
 			delete editor;
 			KMessageBox::messageBox (view (), KMessageBox::Error, i18n ("Unable to open \"%1\"", url.prettyUrl ()), i18n ("Could not open command file"));
 			return false;
