@@ -271,11 +271,15 @@ rktest.setSuiteStandards <- function (suite, basedir=getwd ()) {
 
 ## Initialize test environment
 rktest.initializeEnvironment <- function () {
+	# Almost all tests depend on R2HTML, indirectly, so we should really assume it (or have the user install it) at the start
+	stopifnot (require (R2HTML))
+
 	# By default .rk.rerun.plugin.link() and .rk.make.hr() are silenced during the test runs
 	.rk.rerun.plugin.link <<- .rk.make.hr <<- function (...) { list (...) }
 
 	# This should make the output of rk.graph.on() fixed
 	rk.get.tempfile.name <<- function (prefix, extension) paste (prefix, extension, sep="")
+	options (rk.graphics.type="PNG", rk.graphics.width=480, rk.graphics.height=480)
 
 	# HACK: Override date, so we don't get a difference for each call of rk.header ()
 	# TODO: implement a clean solution inside rk.header()
@@ -289,6 +293,7 @@ rktest.initializeEnvironment <- function () {
 	# Make sure i18n does not get in the way
 	invisible (Sys.setenv (LANGUAGE="C"))
 	if (.Platform$OS.type == "unix") invisible (Sys.setlocale ("LC_MESSAGES", "C"))
+	options (useFancyQuotes=FALSE)
 
 	# This version of rk.set.output.html.file does not notify the frontend of the change. Without this, you'll get lots of output windows.
 	rk.set.output.html.file <<- function (x) {
